@@ -37,10 +37,13 @@ from libra.admin_api.device_pool.manage_pool import Pool
 from libra.admin_api.expunge.expunge import ExpungeScheduler
 from libra.admin_api import config as api_config
 from libra.admin_api import model
+from libra.admin_api import acl
 from libra.openstack.common import importutils
 from libra.openstack.common import log as logging
-from libra.common.options import add_common_opts, CONF
 from libra.common.log import get_descriptors
+from libra.common.options import CONF
+from libra.common.options import add_common_opts
+from libra.common.options import check_gearman_ssl_files
 
 
 LOG = logging.getLogger(__name__)
@@ -88,7 +91,9 @@ def setup_app(pecan_config):
             True)
     )
 
-    return app
+    final_app = acl.AuthDirector(app)
+
+    return final_app
 
 
 class MaintThreads(object):
@@ -117,7 +122,7 @@ class MaintThreads(object):
             usage = UsageStats(self.drivers)
             self.classes.append(usage)
 
-        if CONF['admin_api'].billing_enable:
+        if CONF['billing_enable']:
             billing = BillingStats(self.drivers)
             self.classes.append(billing)
 
@@ -173,6 +178,12 @@ def main():
             context.gid = grp.getgrnam(CONF['group']).gr_gid
         context.open()
 
+    try:
+        check_gearman_ssl_files()
+    except Exception as e:
+        LOG.critical(str(e))
+        return
+
     # Use the root logger due to lots of services using logger
     LOG.info('Starting on %s:%d', CONF.admin_api.host, CONF.admin_api.port)
     api = setup_app(pc)
